import React from 'react'
import { Result, ActivityIndicator, Flex } from 'antd-mobile';
import NativeHook from '@/utils/NativeHook'
import styles from './Daily.less'
import { formatMessage } from 'umi-plugin-react/locale'

class Daily extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      unionList: [],
      activityId: this.props.activityId,
      firstLoad: true,
      winRewards: []
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = formatMessage({ id: 'combine.document.title', defaultMessage: '充值福利' })
    this.getRecharge()      //获取充值活动
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //获取充值活动
  getRecharge() {
    const { activityId } = this.state
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getRecharge',
      params: { activityId },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const unionList = res.data.unionList || []
        for (let item of unionList) {
          const actions = item.actions || []
          const giftList = []
          for (let action of actions) {
            const bagItems = action.bagItems || []
            giftList = [...giftList, ...bagItems]
            //赠送货币
            if (action.actionType === 201) {
              if (action.walletType === 11) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Gems', defaultMessage: '星钻' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 12) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Tokens', defaultMessage: '星元' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 21) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Coins', defaultMessage: '星币' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
            }
            //赠送积分
            if (action.actionType === 301) {
              if (action.scoreType === 11) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Charm', defaultMessage: '财富值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
              if (action.scoreType === 21) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Wealth', defaultMessage: '魅力值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
            }
          }
          const addItems = []
          if (giftList.length % 4) {
            const num = 4 - (giftList.length % 4)
            for (let i = 0; i < num; i++) {
              addItems.push({
                quantity: 0,
                item: {
                  giftName: 'space',
                  giftIcon: ''
                }
              })
            }
          }
          item.giftList = [...giftList, ...addItems]
        }
        this.setState({ firstLoad: false }, () => {
          this.getTodayRecharge(unionList)   //获取今日充值
        })
      } else {
        const errMsg = res.msg
        this.setState({ firstLoad: false, err: true, errMsg })
      }
    })
  }

  //获取今日充值
  getTodayRecharge(unionList) {
    NativeHook.call.getData({
      api: '/api-app/v1/recharge/getTodayRecharge',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const dailyRecharge = res.data.amount ? Number(res.data.amount) : 0
        let allReached = true
        let recentIndex = -1
        if (unionList.length > 0) {
          for (let i in unionList) {
            const item = unionList[i]
            const unionName = Number(item.unionName)
            if ((unionName !== NaN)) {
              if (dailyRecharge >= unionName) {
                //已达到该充值，隐藏
                item.hidden = true
              } else {
                if (recentIndex === -1) {
                  recentIndex = Number(i)
                }
                allReached = false
              }
            }
          }
        }
        recentIndex = recentIndex === -1 ? 0 : recentIndex
        this.setState({ dailyRecharge, unionList, allReached, recentIndex })
      }
    })
  }

  goRecharge = () => {
    NativeHook.go.recharge((res) => {
      if (Object.prototype.toString.call(res) === "[object Object]") {
        const price = Number(res.price || 0)
        // 充值成功
        this.getTodayRecharge(this.state.unionList)
        if (price > 0) {
          this.showWin(price, this.state.unionList)
          NativeHook.go.refreshActivity(() => {
          })
        }
      }
    })
  }

  //显示充值达到的礼品
  showWin(money, unionList) {
    const { dailyRecharge } = this.state
    let winRewards = []
    if (unionList.length > 0) {
      for (let i in unionList) {
        const item = unionList[i]
        const unionName = Number(item.unionName)
        if ((unionName !== NaN)) {
          if (dailyRecharge < unionName && (dailyRecharge + money) >= unionName) {
            //已达到该充值,把所有礼包叠加
            const giftList = item.giftList || []
            winRewards = [...winRewards, ...giftList]
          }
        }
      }
    }
    if (winRewards.length > 0) {
      this.setState({ winRewards, winModal: true })
    }
  }

  onClose = () => {
    console.log('关闭网页')
    NativeHook.call.close()
  }

  closeWinModal = () => {
    this.setState({ winModal: false })
  }

  goBag = () => {
    //前往背包
    NativeHook.go.package(() => {

    })
  }

  render() {
    const { err, errMsg, firstLoad, dailyRecharge, unionList, winRewards, recentIndex, allReached } = this.state
    return (
      <div className={styles.daily}>
        {firstLoad && <ActivityIndicator className={styles.firstLoadLoading} toast animating={true} text={formatMessage({ id: 'loading', defaultMessage: '加载中' })} />}
        {!err && !firstLoad && (
          <div>
            <div className={styles.content}>
              <img className={styles.banner} src={formatMessage({ id: 'combine.banner.daily', defaultMessage: require('@/assets/banner_daily.png') })} />
              <div className={styles.modal}>
                <Flex className={styles['bar-top']} justify="between">
                  <div>
                    {formatMessage({ id: 'daily.today.recharge', defaultMessage: '今日已充值' })}：
                    <span style={{ color: '#FF4D5C' }}>{dailyRecharge}{formatMessage({ id: 'yuan', defaultMessage: '元' })}</span>
                  </div>
                  <div style={{ color: '#FF4D5C' }}
                    onClick={this.onClose}>
                    {formatMessage({ id: 'Top up', defaultMessage: '立即充值' }) + '>'}
                  </div>
                </Flex>
                <div className={styles.list}>
                  {unionList.map((item, i) => {
                    if (item.hidden) return null
                    i = Number(i)
                    const giftList = item.giftList || []
                    const unionName = Number(item.unionName) === NaN ? 0 : Number(item.unionName)
                    return (
                      <div key={i} className={styles['list-item']}>
                        <Flex align="center" justify="between">
                          <div className={styles['item-title']}>
                            {i === recentIndex
                              ? formatMessage({ id: 'Next rewards bag', defaultMessage: '下一个充值礼包' })
                              : formatMessage({ id: 'daily.list.title', defaultMessage: '每日{money}元充值礼包' }, { money: item.unionName })
                            }
                          </div>
                          {i === recentIndex && (
                            <div>
                              {formatMessage({ id: 'daily.left', defaultMessage: '还差 ' })}
                              <span style={{ color: '#FF4D79' }}>{formatMessage({ id: 'daily.list.left.money', defaultMessage: '{money}元 ' }, { money: unionName - dailyRecharge })}</span>
                              {formatMessage({ id: 'more to unlock', defaultMessage: '可领取' })}
                            </div>
                          )}
                        </Flex>
                        <Flex className={styles['list-gift']} justify="between">
                          {giftList.map((gift, a) => {
                            gift.item = gift.item ? gift.item : {}
                            const iconUrl = gift.item.giftIcon || gift.item.propsIcon || gift.item.mountsPreview || gift.item.medalImage
                            const name = gift.item.giftName || gift.item.propsName || gift.item.mountsName || gift.item.medalName
                            return (
                              <div key={a} className={styles.gift} style={{ opacity: name === 'space' ? 0 : 1 }}>
                                <div className={styles.tag}>{gift.quantity}</div>
                                <img alt="iconUrl" className={styles['gift-img']} src={iconUrl} />
                                <div className={`${styles['gift-name']} text-overflow-hidden`}>{name}</div>
                              </div>
                            )
                          })}
                        </Flex>
                      </div>
                    )
                  })}
                  {allReached && <div className={styles['bar-reached']}>{formatMessage({ id: 'daily.empty', defaultMessage: '恭喜您，今日礼包已全部领取！' })}</div>}
                </div>
              </div>
            </div>
            <div className={styles['button-layout']}>
              <div className={styles.button} onClick={this.onClose}>{formatMessage({ id: 'Top up', defaultMessage: '立即充值' })}</div>
            </div>
          </div>
        )}
        {err && (
          <Result
            img={<img alt={formatMessage({ id: 'err', defaultMessage: '信息错误' })} style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title={formatMessage({ id: 'err', defaultMessage: '信息错误' })}
            message={errMsg}
          />
        )}

      </div>
    )
  }
}

export default Daily