import React from 'react'
import { Result, ActivityIndicator } from 'antd-mobile';
import NativeHook from '@/utils/NativeHook'
import Url from '@/utils/Url'
import styles from './Daily.less'
import DailyPop from './components/DailyPop'
import GiftModal from './components/GiftModal';
import { formatMessage } from 'umi-plugin-react/locale';

class Daily extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      unionList: [],
      activityId: Url.getQueryString('id'),
      firstLoad: true,
      winRewards: []
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = formatMessage({ id: 'daily.document.title', defaultMessage: '每日充值礼包' })
    this.getRecharge()      //获取充值活动
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //获取充值活动
  getRecharge() {
    const { activityId } = this.state
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getRecharge',
      params: { activityId },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const unionList = res.data.unionList || []
        for (let item of unionList) {
          const actions = item.actions || []
          const giftList = []
          for (let action of actions) {
            const bagItems = action.bagItems || []
            giftList = [...giftList, ...bagItems]
            //赠送货币
            if (action.actionType === 201) {
              if (action.walletType === 11) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Gems', defaultMessage: '星钻' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 12) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Tokens', defaultMessage: '星元' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 21) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Coins', defaultMessage: '星币' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
            }
            //赠送积分
            if (action.actionType === 301) {
              if (action.scoreType === 11) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Charm', defaultMessage: '财富值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
              if (action.scoreType === 21) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Wealth', defaultMessage: '魅力值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
            }
          }
          item.giftList = giftList
        }
        this.setState({ firstLoad: false }, () => {
          this.getTodayRecharge(unionList)   //获取今日充值
        })
      } else {
        const errMsg = res.msg
        this.setState({ firstLoad: false, err: true, errMsg })
      }
    })
  }

  //获取今日充值
  getTodayRecharge(unionList) {
    NativeHook.call.getData({
      api: '/api-app/v1/recharge/getTodayRecharge',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const dailyRecharge = res.data.amount ? Number(res.data.amount) : 0
        let allReached = true
        let recentIndex = -1
        if (unionList.length > 0) {
          for (let i in unionList) {
            const item = unionList[i]
            const unionName = Number(item.unionName)
            if ((unionName !== NaN)) {
              if (dailyRecharge >= unionName) {
                //已达到该充值，隐藏
                item.hidden = true
              } else {
                if (recentIndex === -1) {
                  recentIndex = Number(i)
                }
                allReached = false
              }
            }
          }
        }
        recentIndex = recentIndex === -1 ? 0 : recentIndex
        this.setState({ dailyRecharge, unionList, allReached, recentIndex })
      }
    })
  }

  goRecharge = () => {
    NativeHook.go.recharge((res) => {
      if (Object.prototype.toString.call(res) === "[object Object]") {
        const price = Number(res.price || 0)
        // 充值成功
        this.getTodayRecharge(this.state.unionList)
        if (price > 0) {
          this.showWin(price, this.state.unionList)
          NativeHook.go.refreshActivity(() => {
          })
        }
      }
    })
  }

  //显示充值达到的礼品
  showWin(money, unionList) {
    const { dailyRecharge } = this.state
    let winRewards = []
    if (unionList.length > 0) {
      for (let i in unionList) {
        const item = unionList[i]
        const unionName = Number(item.unionName)
        if ((unionName !== NaN)) {
          if (dailyRecharge < unionName && (dailyRecharge + money) >= unionName) {
            //已达到该充值,把所有礼包叠加
            const giftList = item.giftList || []
            winRewards = [...winRewards, ...giftList]
          }
        }
      }
    }
    if (winRewards.length > 0) {
      this.setState({ winRewards, winModal: true })
    }
  }

  onClose = () => {
    console.log('关闭网页')
    NativeHook.call.close()
  }

  closeWinModal = () => {
    this.setState({ winModal: false })
  }

  goBag = () => {
    //前往背包
    NativeHook.go.package(() => {

    })
  }

  render() {
    const { err, errMsg, firstLoad, dailyRecharge, unionList, winRewards, recentIndex } = this.state
    return (
      <div className={styles.daily}>
        {firstLoad && <ActivityIndicator className={styles.firstLoadLoading} toast animating={true} text={formatMessage({ id: 'loading', defaultMessage: '加载中' })} />}
        {!err && !firstLoad && (
          <DailyPop
            recentIndex={recentIndex}   //最近一个充值礼包位置
            dailyRecharge={dailyRecharge}
            goRecharge={this.goRecharge}
            list={unionList}
            onClose={this.onClose}
            allReached={this.state.allReached}    //是否全部达成
          />
        )}
        {err && (
          <Result
            img={<img alt="信息错误" style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title={formatMessage({ id: 'err', defaultMessage: '信息错误' })}
            message={errMsg}
          />
        )}
        {winRewards.length > 0 && (
          <GiftModal
            visible={this.state.winModal}
            closeWinModal={this.closeWinModal}
            winRewards={winRewards}
            goBag={this.goBag}
          />
        )}

      </div>
    )
  }
}

export default Daily