import React, { Fragment } from 'react'
import { Result, ActivityIndicator } from 'antd-mobile';
import NativeHook from '@/utils/NativeHook'
import Url from '@/utils/Url'
import styles from './First.less'
import FirstRecharge from './components/FirstRecharge'
import GiftModal from './components/GiftModal';
import { formatMessage } from 'umi-plugin-react/locale';

class First extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      firstList: [],
      activityId: Url.getQueryString('id'),
      firstLoad: true,
      tabName: [],
      winRewards: []
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = formatMessage({ id: 'fist.document.title', defaultMessage: '充值福利' })
    this.getRecharge()      //获取充值活动
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //获取充值活动
  getRecharge() {
    const { activityId } = this.state
    NativeHook.call.getData({
      api: '/api-app/v1/activity/getRecharge',
      params: { activityId },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const firstList = res.data.unionList || []
        for (let item of firstList) {
          const actions = item.actions || []
          const giftList = []
          for (let action of actions) {
            const bagItems = action.bagItems || []
            giftList = [...giftList, ...bagItems]
            //赠送货币
            if (action.actionType === 201) {
              if (action.walletType === 11) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Gems', defaultMessage: '星钻' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 12) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Tokens', defaultMessage: '星元' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
              if (action.walletType === 21) {
                giftList.push({
                  quantity: action.walletAmount,
                  item: {
                    giftName: formatMessage({ id: 'Coins', defaultMessage: '星币' }),
                    giftIcon: require('@/assets/icon_coin.png')
                  }
                })
              }
            }
            //赠送积分
            if (action.actionType === 301) {
              if (action.scoreType === 11) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Charm', defaultMessage: '财富值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
              if (action.scoreType === 21) {
                giftList.push({
                  quantity: action.scoreValue,
                  item: {
                    giftName: formatMessage({ id: 'Wealth', defaultMessage: '魅力值' }),
                    giftIcon: require('@/assets/icon_integral.png')
                  }
                })
              }
            }
          }
          item.giftList = giftList
        }
        const tabName = []
        for (let item of firstList) {
          tabName.push({ title: '￥' + item.unionName })
        }
        this.setState({ firstList, firstLoad: false, tabName })
      } else {
        const errMsg = res.msg
        this.setState({ firstLoad: false, err: true, errMsg })
      }
    })
  }

  goRecharge = () => {
    NativeHook.go.recharge((res) => {
      if (Object.prototype.toString.call(res) === "[object Object]") {
        // 充值成功
        const price = Number(res.price || 0)
        if (price > 0) {
          this.showWin(price)
          //刷新直播间活动
          NativeHook.go.refreshActivity(() => {
          })
        }
      }
    })
  }

  //显示充值达到的礼品
  showWin(money) {
    const { firstList } = this.state
    let winRewards = []
    let closeRecharge = true
    if (firstList.length > 0) {
      for (let i in firstList) {
        const item = firstList[i]
        const unionName = Number(item.unionName)
        if ((unionName !== NaN)) {
          if (Number(money) === unionName) {
            //已达到该充值
            closeRecharge = false
            const hideRechargeModal = true
            winRewards = item.giftList || []
            this.setState({ winRewards, winModal: true, hideRechargeModal })
          }
        }
      }
    }
    //充值金额不匹配
    if (closeRecharge) {
      this.onClose()
    }
  }

  onClose = () => {
    console.log('关闭网页')
    NativeHook.call.close()
  }

  closeWinModal = () => {
    this.onClose()
  }

  goBag = () => {
    //前往背包
    NativeHook.go.package(() => {

    })
  }

  render() {
    const { err, errMsg, firstLoad, tabName, winRewards, hideRechargeModal } = this.state
    return (
      <Fragment>
        {firstLoad && <ActivityIndicator className={styles.firstLoadLoading} toast animating={true} text={formatMessage({ id: 'loading', defaultMessage: '加载中' })} />}
        {!err && !firstLoad && !hideRechargeModal && (
          <div className={styles.wrapper}>
            <FirstRecharge
              goRecharge={this.goRecharge}
              list={this.state.firstList}
              onClose={this.onClose}
              tabName={tabName}
            />
          </div>
        )}
        {err && (
          <Result
            img={<img alt={formatMessage({ id: 'err', defaultMessage: '信息错误' })} style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title={formatMessage({ id: 'err', defaultMessage: '信息错误' })}
            message={errMsg}
          />
        )}
        {winRewards.length > 0 && (
          <GiftModal
            visible={this.state.winModal}
            closeWinModal={this.closeWinModal}
            winRewards={winRewards}
            goBag={this.goBag}
          />
        )}
      </Fragment>
    )
  }
}

export default First